..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Objectives
----------

-  To review the ideas of computer science, programming, and
   problem-solving.

-  To understand abstraction and the role it plays in the
   problem-solving process.

-  To understand and implement the notion of an abstract data type.

-  To review the Python programming language.

